#' @title
#' Display common names
#'
#' @description
#' This function formats the common name for display after replacing the underscores with spaces
#' and adding dashes where required .
#'
#' @param common_name common name to format for display
#'
#' @return common name formatted for display
#' @export
display_common_name <- function(common_name) {

  stringr::str_replace_all(common_name, "-|_", " ") %>%
    dplyr::recode(.,
                  `Bar tailed godwit`= "Bar-tailed godwit",
                  `Bewicks swan`= "Bewick's swan",
                  `Black headed gull`= "Black-headed gull",
                  `Black tailed godwit`= "Black-tailed godwit",
                  `Black throated diver`= "Black-throated diver",
                  `Black winged stilt`= "Black-winged stilt",
                  `Brunnichs guillemot`= "Brünnich's guillemot",
                  `Corys shearwater`= "Cory's shearwater",
                  `European storm petrel`= "European storm-petrel",
                  `Great black backed gull`= "Great black-backed gull",
                  `Black legged kittiwake`= "Black-legged kittiwake",
                  `Leachs storm petrel`= "Leach's storm-petrel",
                  `Lesser black backed gull`= "Lesser black-backed gull",
                  `Long tailed duck`= "Long-tailed duck",
                  `Long tailed skua`= "Long-tailed skua",
                  `Red breasted merganser`= "Red-breasted merganser",
                  `Red necked grebe`= "Red-necked grebe",
                  `Red necked phalarope`= "Red-necked phalarope",
                  `Red throated diver`= "Red-throated diver",
                  `Slender billed gull`= "Slender-billed gull",
                  `Stellers eider`= "Steller's eider",
                  `Greater white fronted goose`= "Greater white-fronted goose",
                  `Yellow legged gull`= "Yellow-legged gull")
}

#' @title
#' Display region and birds subdivision names
#'
#' @description
#' This function displays the region and birds subdivision name for the corresponding
#' region and birds subdivision label.
#'
#' @param ices_colony_label region and birds subdivision label.
#'
#' @return region and birds subdivision name with label in brackets.
#' @export
display_region_subdivision_names <- function(ices_colony_label) {
  dplyr::recode(as.character(ices_colony_label),
                I = "Arctic Waters (OSPAR Region I)",
                Im = "North Barents Sea (OSPAR subdivision Im)",
                In = "South Barents Sea (OSPAR subdivision In)",
                Io = "Norwegian Sea (OSPAR subdivision Io)",
                II = "Greater North Sea (OSPAR Region II)",
                IIa = "Northeast coast of Britain (OSPAR subdivision IIa)",
                IIb = "West coast of Norway (OSPAR subdivision IIb)",
                IIc = "Skagerrak/Kattegat area (OSPAR subdivision IIc)",
                IId = "Southern North Sea (OSPAR subdivision IId)",
                IIe = "The Channel (OSPAR subdivision IIe)",
                IIf = "North coast of Scotland and the Northern Isles (OSPAR subdivision IIf)",
                III = "Celtic Seas (OSPAR Region III)",
                IV = "Bay of Biscay and Iberian Coast (OSPAR Region IV)",
                V = "Wider Atlantic (OSPAR Region V)"
                )
}


