% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/analysis_functions.R
\name{calculate_non_breeding_relative_abundance}
\alias{calculate_non_breeding_relative_abundance}
\title{Calculate and plot species non-breeding relative abundance}
\usage{
calculate_non_breeding_relative_abundance(
  ospar,
  label,
  species_name,
  target_threshold,
  start_year,
  end_year
)
}
\arguments{
\item{ospar}{dataframe of OSPAR region or sub region aggregated yearly abundance counts.}

\item{label}{OSPAR region or sub region label. One of I, Im, In, Io, II, IIa, IIb, IIc, IId IIe, IIf, III, IV, V.}

\item{species_name}{Common name of species}

\item{target_threshold}{Target threshold for species, 0.7 if species lays more than egg, 0.8 for species laying one egg.}

\item{start_year}{Start year of abundance analysis}

\item{end_year}{End year of abundance analysis.}
}
\value{
list containing region or subregions yearly and six year relative abundance means,
for each non-breeding species.
}
\description{
This function calculates relative abundance, six year relative abundance geometric
mean and plots relative abundance trend for non-breeding species.
}
\details{
The function performs the following steps
\itemize{
\item aggregates abundance counts as value for each year (variable) in data frame \strong{ospar.melt}.
Aggregation required for OSPAR regions with sub region counts eg I <- Io, Im, In
\item runs step baseline function to get the predicted start year count from first ten
years regression model or mean of the first ten year if regression is not signifcant
\item calculates the relative abundance for each year by dividing count by baseline count,
stored in \strong{index} vector
\item calculates the six year rolling geometric relative abundance means, stored in
\strong{six_year_mean} vector
\item creates \strong{dat_unsm} dataframe containing years, index and six_year_mean columns
\item creates and exports species yearly relative abundance trend plot for each species+region/sub region
\item returns yearly and six year mean relative abundance values for each species+region/sub region as
\strong{dat_unsm} data frame.
}
}
\seealso{
Other calculate relative abundance functions: 
\code{\link{calculate_breeding_relative_abundance}()}
}
\concept{calculate relative abundance functions}
